Struct csrf::CsrfCookie
[−]
[src]
pub struct CsrfCookie { /* fields omitted */ }A signed, encrypted CSRF cookie that is suitable to be displayed to end users.
Methods
impl CsrfCookie[src]
fn new(bytes: Vec<u8>) -> Self[src]
Create a new cookie from the given token bytes.
fn b64_string(&self) -> String[src]
Get the base64 value of this cookie.
fn value(&self) -> &[u8][src]
Get be raw value of this cookie.